@@ -12,23 +12,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, TypeVar, Union
+from typing import TYPE_CHECKING
 
-from selenium import webdriver
 from selenium.common.exceptions import TimeoutException
 from selenium.webdriver.support.ui import WebDriverWait
 
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
 if TYPE_CHECKING:
-    # noinspection PyUnresolvedReferences
     from appium.webdriver.webdriver import WebDriver
 
-T = TypeVar('T', bound=Union['WebDriver', 'Activities'])
 
-
-class Activities(webdriver.Remote):
-    def start_activity(self: T, app_package: str, app_activity: str, **opts: str) -> T:
+class Activities(CanExecuteCommands):
+    def start_activity(self, app_package: str, app_activity: str, **opts: str) -> 'WebDriver':
         """Opens an arbitrary activity during a test. If the activity belongs to
         another application, that application is started and the activity is opened.
 
@@ -47,10 +44,7 @@ class Activities(webdriver.Remote):
             optional_intent_arguments (str): Optional arguments to the intent.
             dont_stop_app_on_reset (str): Should the app be stopped on reset?
         """
-        data = {
-            'appPackage': app_package,
-            'appActivity': app_activity
-        }
+        data = {'appPackage': app_package, 'appActivity': app_activity}
         arguments = {
             'app_wait_package': 'appWaitPackage',
             'app_wait_activity': 'appWaitActivity',
@@ -58,16 +52,16 @@ class Activities(webdriver.Remote):
             'intent_category': 'intentCategory',
             'intent_flags': 'intentFlags',
             'optional_intent_arguments': 'optionalIntentArguments',
-            'dont_stop_app_on_reset': 'dontStopAppOnReset'
+            'dont_stop_app_on_reset': 'dontStopAppOnReset',
         }
         for key, value in arguments.items():
             if key in opts:
                 data[value] = opts[key]
         self.execute(Command.START_ACTIVITY, data)
-        return self
+        return self  # type: ignore
 
     @property
-    def current_activity(self: T) -> str:
+    def current_activity(self) -> str:
         """Retrieves the current activity running on the device.
 
         Returns:
@@ -75,7 +69,7 @@ class Activities(webdriver.Remote):
         """
         return self.execute(Command.GET_CURRENT_ACTIVITY)['value']
 
-    def wait_activity(self: T, activity: str, timeout: int, interval: int = 1) -> bool:
+    def wait_activity(self, activity: str, timeout: int, interval: int = 1) -> bool:
         """Wait for an activity: block until target activity presents or time out.
 
         This is an Android-only method.
@@ -89,16 +83,19 @@ class Activities(webdriver.Remote):
             `True` if the target activity is shown
         """
         try:
-            WebDriverWait(self, timeout, interval).until(
-                lambda d: d.current_activity == activity)
+            WebDriverWait(self, timeout, interval).until(lambda d: d.current_activity == activity)
             return True
         except TimeoutException:
             return False
 
-    # pylint: disable=protected-access
-    # noinspection PyProtectedMember
-    def _addCommands(self) -> None:
-        self.command_executor._commands[Command.GET_CURRENT_ACTIVITY] = \
-            ('GET', '/session/$sessionId/appium/device/current_activity')
-        self.command_executor._commands[Command.START_ACTIVITY] = \
-            ('POST', '/session/$sessionId/appium/device/start_activity')
+    def _add_commands(self) -> None:
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.GET_CURRENT_ACTIVITY] = (
+            'GET',
+            '/session/$sessionId/appium/device/current_activity',
+        )
+        commands[Command.START_ACTIVITY] = (
+            'POST',
+            '/session/$sessionId/appium/device/start_activity',
+        )
