@@ -12,18 +12,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TypeVar
+from typing import TYPE_CHECKING, Optional
 
 from selenium.webdriver.remote.switch_to import SwitchTo
 
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
+
 from .mobilecommand import MobileCommand
 
-T = TypeVar('T', bound='MobileSwitchTo')
+if TYPE_CHECKING:
+    from appium.webdriver.webdriver import WebDriver
 
 
 class MobileSwitchTo(SwitchTo):
-    def context(self, context_name: str) -> T:
+    _driver: CanExecuteCommands
+
+    def context(self, context_name: Optional[str]) -> 'WebDriver':
         """Sets the context for the current session.
+        Passing `None` is equal to switching to native context.
 
         Args:
             context_name: The name of the context to switch to.
@@ -32,4 +38,5 @@ class MobileSwitchTo(SwitchTo):
             driver.switch_to.context('WEBVIEW_1')
         """
         self._driver.execute(MobileCommand.SWITCH_TO_CONTEXT, {'name': context_name})
+        # noinspection PyTypeChecker
         return self
